@@ -470,7 +470,7 @@ static CLIF_option option_list[] = {
 			    CLIF_set_flag, &as_lookups, 0, 0 },
 	{ "M", "module", "name", "Use specified module (either builtin or "
 			    "external) for traceroute operations. Most methods "
-			    "have their shortcuts (`-I' mean `-M icmp' etc.)",
+			    "have their shortcuts (`-I' means `-M icmp' etc.)",
 			    CLIF_set_string, &module, 0, CLIF_EXTRA },
 	{ "O", "options", "OPTS", "Use module-specific option %s for the "
 			    "traceroute module. Several %s allowed, separated "
